/**
 * DynamicReports - Free Java reporting library for creating reports dynamically
 *
 * Copyright (C) 2010 - 2012 Ricardo Mariaca
 * http://dynamicreports.sourceforge.net
 *
 * This file is part of DynamicReports.
 *
 * DynamicReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * DynamicReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with DynamicReports. If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.dynamicreports.test.jasper.group;

import static net.sf.dynamicreports.report.builder.DynamicReports.*;

import java.util.Date;
import java.util.Locale;

import net.sf.dynamicreports.jasper.builder.JasperReportBuilder;
import net.sf.dynamicreports.report.builder.column.TextColumnBuilder;
import net.sf.dynamicreports.report.builder.group.ColumnGroupBuilder;
import net.sf.dynamicreports.report.datasource.DRDataSource;
import net.sf.dynamicreports.test.jasper.AbstractJasperValueTest;
import net.sf.jasperreports.engine.JRDataSource;

/**
 * @author Ricardo Mariaca (dynamicreports@gmail.com)
 */
public class DataTypeGroupTest extends AbstractJasperValueTest {
	private TextColumnBuilder<Date> column1;
	private TextColumnBuilder<Date> column2;
	private ColumnGroupBuilder group1;

	@Override
	protected void configureReport(JasperReportBuilder rb) {
		rb.setLocale(Locale.ENGLISH)
		  .columns(
		  	column1 = col.column("Column1", "field1", type.dateMonthType()),
				column2 = col.column("Column2", "field1", type.dateType()))
			.groupBy(
					group1 = grp.group(column1)
					            .groupByDataType());
	}

	@Override
	public void test() {
		super.test();

		numberOfPagesTest(1);

		//column2
		columnTitleCountTest(column2, 1);
		columnTitleValueTest(column2, "Column2");
		columnDetailCountTest(column2, 2);
		columnDetailValueTest(column2, "01/01/2010", "02/01/2010");

		//group1
		groupHeaderTitleCountTest(group1, 0);
		groupHeaderCountTest(group1, 2);
		groupHeaderValueTest(group1, "January", "February");
	}

	@Override
	protected JRDataSource createDataSource() {
		DRDataSource dataSource = new DRDataSource("field1");
		for (int i = 0; i < 1; i++) {
			dataSource.add(toDate(2010, 1, 1));
			dataSource.add(toDate(2010, 2, 1));
		}
		return dataSource;
	}
}
